==> hubzero-submit-pegasus_4.5.2-3+deb8.tar.gz: pegasus-4.5.2/share/doc/pegasus/html/service.php <==
<?php  
            include_once( $_SERVER['DOCUMENT_ROOT']."/static/includes/common.inc.php" );
            do_html_header("Documentation");
        ?><div id="content">
<div class="navheader">
<table width="100%" summary="Navigation header"><tr>
<td width="20%" align="left">
<a accesskey="p" href="job_throttling.php">Prev</a> </td>
<td width="60%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="20%" align="right"> <a accesskey="n" href="ch11s02.php">Next</a>
</td>
</tr></table>
<hr>
</div>
<div class="chapter">
<div class="titlepage"><div><div><h1 class="title">
<a name="service"></a>Chapter 11. Pegasus Service</h1></div></div></div>
<div class="toc"><dl class="toc">
<dt><span class="section"><a href="service.php#idp50704208">11.1. Service Administration</a></span></dt>
<dt><span class="section"><a href="ch11s02.php">11.2. Dashboard</a></span></dt>
<dt><span class="section"><a href="ch11s03.php">11.3. Running Pegasus Service under Apache HTTPD</a></span></dt>
<dt><span class="section"><a href="ch11s04.php">11.4. Ensemble Manager</a></span></dt>
</dl></div>
<div class="section">
<div class="titlepage"><div><div><h2 class="title" style="clear: both">
<a name="idp50704208"></a>11.1. Service Administration</h2></div></div></div>
<div class="toc"><dl class="toc">
<dt><span class="section"><a href="service.php#idp47120976">11.1.1. Service Configuration</a></span></dt>
<dt><span class="section"><a href="service.php#idp47518800">11.1.2. Running the Service</a></span></dt>
</dl></div>
<div class="section">
<div class="titlepage"><div><div><h3 class="title">
<a name="idp47120976"></a>11.1.1. Service Configuration</h3></div></div></div>
<p>Create a file called service.py in $HOME/.pegasus/ OR modify the
      lib/pegasus/python/Pegasus/service/defaults.py file. The servuce can be
      configured using the properties described below.</p>
<div class="table">
<a name="idp53905456"></a><p class="title"><b>Table 11.1. Pegasus Service Configuration Options</b></p>
<div class="table-contents"><table summary="Pegasus Service Configuration Options" border="1">
<colgroup>
<col>
<col>
<col>
</colgroup>
<thead><tr>
<th align="center">Property</th>
<th>Default Value</th>
<th>Description</th>
</tr></thead>
<tbody>
<tr>
<td>SERVER_HOST</td>
<td>127.0.0.1</td>
<td>SERVER_HOST specifies the hostname/network interface on
                which the service listens for requests.</td>
</tr>
<tr>
<td>SERVER_PORT</td>
<td>5000</td>
<td>SERVER_PORT specifies the port number on which the
                service listens for requests.</td>
</tr>
<tr>
<td>CERTIFICATE</td>
<td>None</td>
<td>SSL certificate file used to encrypt sessions. If no
                certificate, key files are provided the service will generate
                and use self-signed certificates.</td>
</tr>
<tr>
<td>PRIVATE_KEY</td>
<td>None</td>
<td>SSL key file used to encrypt connections. If no
                certificate, key files are provided the service will generate
                and use self-signed certificates. </td>
</tr>
<tr>
<td>AUTHENTICATION</td>
<td>PAMAuthentication</td>
<td>By default the service uses PAM authentication i.e.
                When prompted for a username and password users can use the
                credentials that they use to login to the machine. Users can
                specify NoAuthentication to disable username/password prompt.
                </td>
</tr>
<tr>
<td>ADMIN_USERS</td>
<td>None</td>
<td>ADMIN_USERS can be used to specify which users have the
                ability to access other users workflow info. If ADMIN_USERS is
                None, False, or '' then users can only access their own
                workflow information. If ADMIN_USERS is '*' then all users are
                admin users and can access everyones workflow information. If
                ADMIN_USERS = {'u1', .., 'un'} OR ['u1', .., 'un'] then only
                users u1, .., un can access other users workflow
                information.</td>
</tr>
<tr>
<td>PROCESS_SWITCHING</td>
<td>True</td>
<td>File created by running Pegasus workflows have
                permissions as per user configuration. So one user migt not be
                able to view workflow information of other users. Setting
                PROCESS_SWITCHING to True makes the service change the process
                UID to the UID of the user whose information is being
                requested. pegasus-service must be started as root for
                PROCESS_SWITCHING to work. PROCESS_SWITCHING can be set to
                False. </td>
</tr>
<tr>
<td>USERNAME</td>
<td>''</td>
<td>The username which pegasus-em client uses to connect to
                the pegasus-em server.</td>
</tr>
<tr>
<td>PASSWORD</td>
<td>''</td>
<td>The password which pegasus-em client uses to connect to
                the pegasus-em server.</td>
</tr>
</tbody>
</table></div>
</div>
<p><br class="table-break"></p>
<p>All clients that connect to the web API will require the USERNAME
      and PASSWORD settings in the configuration file.</p>
</div>
<div class="section">
<div class="titlepage"><div><div><h3 class="title">
<a name="idp47518800"></a>11.1.2. Running the Service</h3></div></div></div>
<p>Pegasus Service can be started using the pegasus-service command
      as follows</p>
<pre class="programlisting">$ pegasus-service</pre>
<p>By default, the server will start on <a class="ulink" href="http://localhost:5000" target="_top">https://localhost:5000</a>. You can set
      the host and port in the configuration file OR pass it as a command line
      switch to pegasus-service as follows.</p>
<pre class="programlisting">$ pegasus-service --hostname &lt;SERVER_HOSTNAME&gt; --port &lt;SERVER_PORT&gt;</pre>
</div>
</div>
</div>
<div class="navfooter">
<hr>
<table width="100%" summary="Navigation footer">
<tr>
<td width="40%" align="left">
<a accesskey="p" href="job_throttling.php">Prev</a> </td>
<td width="20%" align="center"> </td>
<td width="40%" align="right"> <a accesskey="n" href="ch11s02.php">Next</a>
</td>
</tr>
<tr>
<td width="40%" align="left" valign="top">10.6. Job Throttling </td>
<td width="20%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="40%" align="right" valign="top"> 11.2. Dashboard</td>
</tr>
</table>
</div>
</div><?php  
            do_html_footer();
        ?>

==> hubzero-submit-pegasus_4.5.2-4+deb8.tar.gz: pegasus-4.5.2/share/doc/pegasus/html/service.php <==
<?php  
            include_once( $_SERVER['DOCUMENT_ROOT']."/static/includes/common.inc.php" );
            do_html_header("Documentation");
        ?><div id="content">
<div class="navheader">
<table width="100%" summary="Navigation header"><tr>
<td width="20%" align="left">
<a accesskey="p" href="job_throttling.php">Prev</a> </td>
<td width="60%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="20%" align="right"> <a accesskey="n" href="ch11s02.php">Next</a>
</td>
</tr></table>
<hr>
</div>
<div class="chapter" title="Chapter 11. Pegasus Service">
<div class="titlepage"><div><div><h2 class="title">
<a name="service"></a>Chapter 11. Pegasus Service</h2></div></div></div>
<div class="toc"><dl>
<dt><span class="section"><a href="service.php#idp37074448">11.1. Service Administration</a></span></dt>
<dt><span class="section"><a href="ch11s02.php">11.2. Dashboard</a></span></dt>
<dt><span class="section"><a href="ch11s03.php">11.3. Running Pegasus Service under Apache HTTPD</a></span></dt>
<dt><span class="section"><a href="ch11s04.php">11.4. Ensemble Manager</a></span></dt>
</dl></div>
<div class="section" title="11.1. Service Administration">
<div class="titlepage"><div><div><h2 class="title" style="clear: both">
<a name="idp37074448"></a>11.1. Service Administration</h2></div></div></div>
<div class="toc"><dl>
<dt><span class="section"><a href="service.php#idp43174480">11.1.1. Service Configuration</a></span></dt>
<dt><span class="section"><a href="service.php#idp40985952">11.1.2. Running the Service</a></span></dt>
</dl></div>
<div class="section" title="11.1.1. Service Configuration">
<div class="titlepage"><div><div><h3 class="title">
<a name="idp43174480"></a>11.1.1. Service Configuration</h3></div></div></div>
<p>Create a file called service.py in $HOME/.pegasus/ OR modify the
      lib/pegasus/python/Pegasus/service/defaults.py file. The servuce can be
      configured using the properties described below.</p>
<div class="table">
<a name="idp34491936"></a><p class="title"><b>Table 11.1. Pegasus Service Configuration Options</b></p>
<div class="table-contents"><table summary="Pegasus Service Configuration Options" border="1">
<colgroup>
<col>
<col>
<col>
</colgroup>
<thead><tr>
<th align="center">Property</th>
<th>Default Value</th>
<th>Description</th>
</tr></thead>
<tbody>
<tr>
<td>SERVER_HOST</td>
<td>127.0.0.1</td>
<td>SERVER_HOST specifies the hostname/network interface on
                which the service listens for requests.</td>
</tr>
<tr>
<td>SERVER_PORT</td>
<td>5000</td>
<td>SERVER_PORT specifies the port number on which the
                service listens for requests.</td>
</tr>
<tr>
<td>CERTIFICATE</td>
<td>None</td>
<td>SSL certificate file used to encrypt sessions. If no
                certificate, key files are provided the service will generate
                and use self-signed certificates.</td>
</tr>
<tr>
<td>PRIVATE_KEY</td>
<td>None</td>
<td>SSL key file used to encrypt connections. If no
                certificate, key files are provided the service will generate
                and use self-signed certificates. </td>
</tr>
<tr>
<td>AUTHENTICATION</td>
<td>PAMAuthentication</td>
<td>By default the service uses PAM authentication i.e.
                When prompted for a username and password users can use the
                credentials that they use to login to the machine. Users can
                specify NoAuthentication to disable username/password prompt.
                </td>
</tr>
<tr>
<td>ADMIN_USERS</td>
<td>None</td>
<td>ADMIN_USERS can be used to specify which users have the
                ability to access other users workflow info. If ADMIN_USERS is
                None, False, or '' then users can only access their own
                workflow information. If ADMIN_USERS is '*' then all users are
                admin users and can access everyones workflow information. If
                ADMIN_USERS = {'u1', .., 'un'} OR ['u1', .., 'un'] then only
                users u1, .., un can access other users workflow
                information.</td>
</tr>
<tr>
<td>PROCESS_SWITCHING</td>
<td>True</td>
<td>File created by running Pegasus workflows have
                permissions as per user configuration. So one user migt not be
                able to view workflow information of other users. Setting
                PROCESS_SWITCHING to True makes the service change the process
                UID to the UID of the user whose information is being
                requested. pegasus-service must be started as root for
                PROCESS_SWITCHING to work. PROCESS_SWITCHING can be set to
                False. </td>
</tr>
<tr>
<td>USERNAME</td>
<td>''</td>
<td>The username which pegasus-em client uses to connect to
                the pegasus-em server.</td>
</tr>
<tr>
<td>PASSWORD</td>
<td>''</td>
<td>The password which pegasus-em client uses to connect to
                the pegasus-em server.</td>
</tr>
</tbody>
</table></div>
</div>
<p><br class="table-break"></p>
<p>All clients that connect to the web API will require the USERNAME
      and PASSWORD settings in the configuration file.</p>
</div>
<div class="section" title="11.1.2. Running the Service">
<div class="titlepage"><div><div><h3 class="title">
<a name="idp40985952"></a>11.1.2. Running the Service</h3></div></div></div>
<p>Pegasus Service can be started using the pegasus-service command
      as follows</p>
<pre class="programlisting">$ pegasus-service</pre>
<p>By default, the server will start on <a class="ulink" href="http://localhost:5000" target="_top">https://localhost:5000</a>. You can set
      the host and port in the configuration file OR pass it as a command line
      switch to pegasus-service as follows.</p>
<pre class="programlisting">$ pegasus-service --hostname &lt;SERVER_HOSTNAME&gt; --port &lt;SERVER_PORT&gt;</pre>
</div>
</div>
</div>
<div class="navfooter">
<hr>
<table width="100%" summary="Navigation footer">
<tr>
<td width="40%" align="left">
<a accesskey="p" href="job_throttling.php">Prev</a> </td>
<td width="20%" align="center"> </td>
<td width="40%" align="right"> <a accesskey="n" href="ch11s02.php">Next</a>
</td>
</tr>
<tr>
<td width="40%" align="left" valign="top">10.6. Job Throttling </td>
<td width="20%" align="center"><a accesskey="h" href="index.php">Table of Contents</a></td>
<td width="40%" align="right" valign="top"> 11.2. Dashboard</td>
</tr>
</table>
</div>
</div><?php  
            do_html_footer();
        ?>
